import openstack
from keystoneauth1 import session
from keystoneauth1 import loading
from novaclient import client


class OpenStackConnection(object):
    """Class for handling the connection to the OpenStack Manager.
        It creates a connection member variable which holds the connection.
        The connection only connects when something called in it."""

    def __init__(self, auth):
        self.openstack = openstack.connect(auth_url=auth["auth_url"],
                                           username=auth["username"],
                                           password=auth["password"],
                                           project_id=auth["project_id"],
                                           project_name=auth["project_name"],
                                           region_name=auth["region_name"]
                                           )

        loader = loading.get_plugin_loader('password')

        auth = loader.load_from_options(auth_url=auth["auth_url"],
                                        username=auth["username"],
                                        user_domain_name="default",
                                        password=auth["password"],
                                        project_id=auth["project_id"],
                                        project_name=auth["project_name"])

        client_session = session.Session(auth=auth)

        self.nova_client = client.Client("2", session=client_session)
